Hello community,

here is the log from the commit of package kwin5 for openSUSE:Factory checked 
in at 2016-08-29 15:27:48
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/kwin5 (Old)
 and      /work/SRC/openSUSE:Factory/.kwin5.new (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "kwin5"

Changes:
--------
--- /work/SRC/openSUSE:Factory/kwin5/kwin5.changes      2016-08-12 
15:40:03.000000000 +0200
+++ /work/SRC/openSUSE:Factory/.kwin5.new/kwin5.changes 2016-08-29 
15:27:51.000000000 +0200
@@ -1,0 +2,8 @@
+Fri Aug 26 20:36:41 UTC 2016 - fab...@ritter-vogt.de
+
+- Update to 5.7.4
+  * New bugfix release
+  * For more details please see:
+    https://www.kde.org/announcements/plasma-5.7.4.php
+
+-------------------------------------------------------------------

Old:
----
  kwin-5.7.3.tar.xz

New:
----
  kwin-5.7.4.tar.xz

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ kwin5.spec ++++++
--- /var/tmp/diff_new_pack.5XSy9X/_old  2016-08-29 15:27:52.000000000 +0200
+++ /var/tmp/diff_new_pack.5XSy9X/_new  2016-08-29 15:27:52.000000000 +0200
@@ -18,7 +18,7 @@
 
 %bcond_without lang
 Name:           kwin5
-Version:        5.7.3
+Version:        5.7.4
 Release:        0
 Summary:        KDE Window Manager
 License:        GPL-2.0+

++++++ kwin-5.7.3.tar.xz -> kwin-5.7.4.tar.xz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/CMakeLists.txt 
new/kwin-5.7.4/CMakeLists.txt
--- old/kwin-5.7.3/CMakeLists.txt       2016-08-02 11:40:59.000000000 +0200
+++ new/kwin-5.7.4/CMakeLists.txt       2016-08-23 14:47:53.000000000 +0200
@@ -1,5 +1,5 @@
 project(KWIN)
-set(PROJECT_VERSION "5.7.3")
+set(PROJECT_VERSION "5.7.4")
 set(PROJECT_VERSION_MAJOR 5)
 
 cmake_minimum_required(VERSION 2.8.12 FATAL_ERROR)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/autotests/test_xrandr_screens.cpp 
new/kwin-5.7.4/autotests/test_xrandr_screens.cpp
--- old/kwin-5.7.3/autotests/test_xrandr_screens.cpp    2016-08-02 
11:40:08.000000000 +0200
+++ new/kwin-5.7.4/autotests/test_xrandr_screens.cpp    2016-08-23 
14:46:16.000000000 +0200
@@ -138,7 +138,7 @@
     QVERIFY(screens->eventType() != 0);
     QCOMPARE(screens->eventType(), 
Xcb::Extensions::self()->randrNotifyEvent());
     QCOMPARE(screens->extension(), 0);
-    QCOMPARE(screens->genericEventType(), 0);
+    QCOMPARE(screens->genericEventTypes(), QVector<int>{0});
     screens->init();
     QRect xephyrDefault = QRect(0, 0, 640, 480);
     QCOMPARE(screens->count(), 1);
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/autotests/wayland/lockscreen.cpp 
new/kwin-5.7.4/autotests/wayland/lockscreen.cpp
--- old/kwin-5.7.3/autotests/wayland/lockscreen.cpp     2016-08-02 
11:40:08.000000000 +0200
+++ new/kwin-5.7.4/autotests/wayland/lockscreen.cpp     2016-08-23 
14:46:16.000000000 +0200
@@ -343,6 +343,8 @@
 
     QScopedPointer<Pointer> pointer(m_seat->createPointer());
     QVERIFY(!pointer.isNull());
+    QSignalSpy enteredSpy(pointer.data(), &Pointer::entered);
+    QVERIFY(enteredSpy.isValid());
     QSignalSpy buttonChangedSpy(pointer.data(), &Pointer::buttonStateChanged);
     QVERIFY(buttonChangedSpy.isValid());
 
@@ -352,6 +354,7 @@
     // first move cursor into the center of the window
     quint32 timestamp = 1;
     MOTION(c->geometry().center());
+    QVERIFY(enteredSpy.wait());
     // and simulate a click
     PRESS;
     QVERIFY(buttonChangedSpy.wait());
@@ -367,6 +370,8 @@
     QVERIFY(!buttonChangedSpy.wait(100));
 
     UNLOCK
+    QVERIFY(enteredSpy.wait());
+    QCOMPARE(enteredSpy.count(), 2);
 
     // and click again
     PRESS;
@@ -383,6 +388,8 @@
     QVERIFY(!pointer.isNull());
     QSignalSpy axisChangedSpy(pointer.data(), &Pointer::axisChanged);
     QVERIFY(axisChangedSpy.isValid());
+    QSignalSpy enteredSpy(pointer.data(), &Pointer::entered);
+    QVERIFY(enteredSpy.isValid());
 
     AbstractClient *c = showWindow();
     QVERIFY(c);
@@ -390,6 +397,7 @@
     // first move cursor into the center of the window
     quint32 timestamp = 1;
     MOTION(c->geometry().center());
+    QVERIFY(enteredSpy.wait());
     // and simulate axis
     kwinApp()->platform()->pointerAxisHorizontal(5.0, timestamp++);
     QVERIFY(axisChangedSpy.wait());
@@ -404,6 +412,8 @@
 
     // and unlock
     UNLOCK
+    QVERIFY(enteredSpy.wait());
+    QCOMPARE(enteredSpy.count(), 2);
 
     // and move axis again
     kwinApp()->platform()->pointerAxisHorizontal(5.0, timestamp++);
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/autotests/wayland/pointer_input.cpp 
new/kwin-5.7.4/autotests/wayland/pointer_input.cpp
--- old/kwin-5.7.3/autotests/wayland/pointer_input.cpp  2016-08-02 
11:40:08.000000000 +0200
+++ new/kwin-5.7.4/autotests/wayland/pointer_input.cpp  2016-08-23 
14:46:16.000000000 +0200
@@ -232,6 +232,7 @@
     Cursor::setPos(QPoint(25, 25));
     QVERIFY(enteredSpy.wait());
     QCOMPARE(enteredSpy.count(), 1);
+    QCOMPARE(enteredSpy.first().at(1).toPointF(), QPointF(25, 25));
     // window should have focus
     QCOMPARE(pointer->enteredSurface(), surface);
     // also on the server
@@ -274,15 +275,12 @@
     // enter
     kwinApp()->platform()->pointerMotion(QPointF(25, 25), 1);
     QVERIFY(enteredSpy.wait());
-    // we get a move event together with the enter, that's actually wrong but 
also shouldn't harm
-    QVERIFY(movedSpy.wait());
-    QCOMPARE(movedSpy.count(), 1);
-    QCOMPARE(movedSpy.first().first().toPointF(), QPointF(25, 25));
+    QCOMPARE(enteredSpy.first().at(1).toPointF(), QPointF(25, 25));
 
     // now warp
     Cursor::setPos(QPoint(26, 26));
     QVERIFY(movedSpy.wait());
-    QCOMPARE(movedSpy.count(), 2);
+    QCOMPARE(movedSpy.count(), 1);
     QCOMPARE(movedSpy.last().first().toPointF(), QPointF(26, 26));
 }
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/cursor.cpp new/kwin-5.7.4/cursor.cpp
--- old/kwin-5.7.3/cursor.cpp   2016-08-02 11:40:08.000000000 +0200
+++ new/kwin-5.7.4/cursor.cpp   2016-08-23 14:46:16.000000000 +0200
@@ -263,7 +263,7 @@
 {
 public:
     XInputEventFilter(X11Cursor *parent, int xi_opcode)
-        : X11EventFilter(XCB_GE_GENERIC, xi_opcode, XI_RawMotion)
+        : X11EventFilter(XCB_GE_GENERIC, xi_opcode, QVector<int>{XI_RawMotion, 
XI_RawButtonPress, XI_RawButtonRelease})
         , m_x11Cursor(parent)
         {}
     virtual ~XInputEventFilter() = default;
@@ -389,6 +389,8 @@
         memset(mask1, 0, sizeof(mask1));
 
         XISetMask(mask1, XI_RawMotion);
+        XISetMask(mask1, XI_RawButtonPress);
+        XISetMask(mask1, XI_RawButtonRelease);
 
         evmasks[0].deviceid = XIAllMasterDevices;
         evmasks[0].mask_len = sizeof(mask1);
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/events.cpp new/kwin-5.7.4/events.cpp
--- old/kwin-5.7.3/events.cpp   2016-08-02 11:40:08.000000000 +0200
+++ new/kwin-5.7.4/events.cpp   2016-08-23 14:46:16.000000000 +0200
@@ -237,7 +237,7 @@
         xcb_ge_generic_event_t *ge = reinterpret_cast<xcb_ge_generic_event_t 
*>(e);
 
         foreach (X11EventFilter *filter, m_genericEventFilters) {
-            if (filter->extension() == ge->extension && 
filter->genericEventType() == ge->event_type && filter->event(e)) {
+            if (filter->extension() == ge->extension && 
filter->genericEventTypes().contains(ge->event_type) && filter->event(e)) {
                 return true;
             }
         }
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' 
old/kwin-5.7.3/kcmkwin/kwincompositing/kcmkwineffects.desktop 
new/kwin-5.7.4/kcmkwin/kwincompositing/kcmkwineffects.desktop
--- old/kwin-5.7.3/kcmkwin/kwincompositing/kcmkwineffects.desktop       
2016-08-02 11:40:08.000000000 +0200
+++ new/kwin-5.7.4/kcmkwin/kwincompositing/kcmkwineffects.desktop       
2016-08-23 14:46:16.000000000 +0200
@@ -120,6 +120,7 @@
 X-KDE-Keywords[pl]=kwin,okno,menadżer,efekt,efekty 3D,efekty 2D,efekty 
graficzne,efekty pulpitu,animacje,różne animacje,efekty zarządzania 
oknami,efekty przełączania okien,efekty przełączania pulpitów,animacje,animacje 
pulpitu,sterowniki,ustawienia sterowników,renderowania, efekt odwrócenia,szkło 
powiększające,efekt powiększenia,efekt pomocnika przyciągania, efekt śledzenia 
myszy,efekt przybliżenia,rozmycie,tablica,efekt eksplozji,efekt zanikania,efekt 
zanikania pulpitu,efekt rozpadania,efekt slajdu,efekt podświetlania okna, efekt 
logowania,efekt wylogowywania,efekt magicznej lampy,efekt animacji 
minimalizacji, efekt znacznika myszy,efekt skalowania,efekt zrzutu ekranu,efekt 
arkusza,efekt slajdu,efekt wysuwających się elementów wyskakujących,efekt 
prześwitywania,przezroczystość,efekt geometrii okna,efekt chwiejnych 
okien,efekt odczuć przy starcie,efekt okna rodzica,efekt przyciemniania 
nieaktywnych,efekt przyciemniania ekranu,efekt przesuwania do tył,efekt 
pokazania ilości klatek na sekundę
 X-KDE-Keywords[pt]=kwin,janela,gestor,composição,efeito,efeitos 3D,efeitos 
2D,OpenGL,XRender,configuração do vídeo,efeitos gráficos,efeitos do 
ecrã,animações,animações diversas,efeitos de gestão das janelas,efeito de 
mudança de janelas,efeito de mudança de ecrãs,animações,velocidade da 
animação,animações do ecrã,controladores,configuração dos 
controladores,desenho,efeito de inversão,efeito de lupa,efeito de lente,efeito 
de ajuda no ajuste, efeito de seguimento do rato,efeito de ampliação,efeito de 
borrão,efeito de quadro,efeito de explosão,efeito de desvanecimento,efeito de 
desvanecimento do ecrã,efeito de destruição,efeito de deslizamento,efeito de 
realce da janela,efeito na autenticação,efeito do encerramento,efeito de 
lâmpada mágica,efeito de animação na minimização,efeito de marcação com 
rato,efeito de escala,efeito de captura do ecrã,efeito de folha,efeito de 
mensagens deslizantes,efeito de miniaturas na barra de tarefas,efeito de 
miniaturas laterais,efeito de janelas a tremer,efeito do arranque 
inicial,efeito da janela-mãe,efeito de escurecimento de janelas 
inactivas,efeito de deslize para trás,efeitos visuais,beleza,efeito de 
apresentação das IPS,efeito de pintura,efeito de mudança em caixa,efeito de 
mudança de capas, efeito de animação do cubo do ecrã,efeito de grelha do 
ecrã,efeito de mudança por viragem,efeito de destaque,efeito de apresentação 
das janelas,efeito de dimensionamento das janelas
 X-KDE-Keywords[pt_BR]=kwin,janela,gerenciador,efeito,efeitos 3D,efeitos 
2D,efeitos gráficos,efeitos da área de trabalho,animações,animações 
diversas,efeitos do gerenciamento de janelas,efeito de mudança de 
janelas,efeito de mudança de área de trabalho,animações da área de 
trabalho,drivers,configuração dos drivers,desenho,renderização,efeito de 
inversão,efeito de lupa,efeito de lente,efeito de ajuda no ajuste,efeito de 
rastreamento do mouse,efeito de ampliação,efeito de borrão,efeito de 
explosão,efeito de escurecimento,efeito de escurecimento da área de 
trabalho,efeito de destruição,efeito de deslizamento,efeito de realce da 
janela,efeito na autenticação,efeito de encerramento de sessão,efeito de 
lâmpada mágica,efeito de animação na minimização,efeito de marcação com 
mouse,efeito em escala,efeito de captura de tela,efeito de folha,efeito de 
slide,efeito de mensagens deslizantes,efeito de miniaturas na barra de 
tarefas,efeito de miniaturas laterais,transparência,efeito de 
transparência,efeito de geometria de janelas,efeito de janelas trêmulas,efeito 
do inicialização,efeito da janela-mãe,efeito de escurecimento de janelas 
inativas,efeito de deslize para trás,efeitos visuais,beleza,efeito de 
apresentação de FPS,efeito de pintura,efeito de mudança em caixa,efeito de 
mudança de capas,efeito de animação do cubo da área de trabalho,efeito de grade 
da área de trabalho,efeito de mudança em pilha,efeito de destaque,efeito de 
apresentação das janelas,efeito de dimensionamento das janelas
+X-KDE-Keywords[ru]=kwin,window,manager,effect,3D effects,2D effects,graphical 
effects,desktop effects,animations,various animations,window management 
effects,window switching effect,desktop switching effect,animations,desktop 
animations,drivers,driver settings,rendering,render,invert effect,looking glass 
effect,magnifier effect,snap helper effect,track mouse effect,zoom effect,blur 
effect,explosion effect,fade effect,fade desktop effect,fall apart effect,glide 
effect,highlight window effect,login effect,logout effect,magic lamp 
effect,minimize animation effect,mouse mark effect,scale in effect,screenshot 
effect,sheet effect,slide effect,sliding popups effect,taskbar thumbnails 
effect,thumbnail aside effect,translucency,translucency 
effect,transparency,window geometry effect,wobbly windows effect,startup 
feedback effect,dialog parent effect,dim inactive effect,dim screen 
effect,slide back effect,eye candy,candy,show FPS effect,show paint effect,box 
switch effect,cover switch effect,desktop cube effect,desktop cube animation 
effect,desktop grid effect,flip switch effect,outline effect,present windows 
effect,resize window effect,эффекты рабочего стола,графические 
эффекты,рендеринг,параметры видео,настройка видео,трёхмерные эффекты,двумерные 
эффекты,эффекты управления окнами,эффекты диспетчера окон,анимация куба рабочих 
столов,плавная смена рабочих столов,прокрутка,анимация всплывающих 
окон,анимация появления окна,вход в систему,завершение сеанса,завершение 
работы,колышущиеся окна,болтающиеся окна,колыхание окон,край 
экрана,лист,анимация распахивания,анимация максимизации,максимизация 
окна,распахивание окна,миниатюры окон сбоку,миниатюры окон на краю 
экрана,полупрозрачность окон,размытие фона,размывание фона,распад закрывающихся 
окон,растворение закрывающихся окон,рисование на экране,рисование мышью на 
экране,скольжение окон,анимация сворачивания,сворачивание окон,волшебная 
лампа,график производительности,производительность эффектов,подсветка 
отрисовки,подсветка рендеринга,подсветка обновляемых частей экрана,анимация 
щелчка мышью,инверсия цветов,инвертирование цветов,поиск курсора мыши,разметка 
экрана,сетка на экране,линейки на экране,экранная разметка,экранная 
сетка,линза,искажение линзой,лупа,увеличение области экрана,масштаб рабочего 
стола,изменение масштаба рабочего стола,управление окнами,специальные 
возможности,инструменты,внешний вид,анимация переключения рабочих столов,все 
окна,просмотр всех окон,все рабочие столы,просмотр всех рабочих 
столов,изменение размера окна,масштабирование текстуры окна,куб с рабочими 
столами,перелистывание окон,управление фокусом,затемнение неактивных 
окон,затемнение основного окна,затемнение под диалогом,затемнение экрана при 
административной задаче,соскальзывание окон при смене фокуса
 X-KDE-Keywords[sk]=kwin, okno, manažér, kompozícia, efekt, 3D efekty, 2D 
efekty, OpenGL, XRender,nastavenia obrazu, grafické efekty, desktop efekty, 
animácie, rôzneanimácie, efekty správa okien, okno prepínanie efektov, 
stolnýspínacie efekt, animácie, animácie rýchlosť, stolný animácie, 
ovládače,nastavenie ovládača, renderovanie, poskytnúť, invertný skutočnosti 
zrkadlá účinok,lupa efekt, snap pomocník efekt, trať myš efekt, zoom efekt, 
rozmazaniuúčinok, prístrojová doska efekt, výbuch efekt, fade efekt, fade 
stolný efekt,rozpadnúť účinok, zostupovej efekt, zvýraznenie okno efekt, efekt 
prihlásenie, odhlásenieúčinok, čarovnú lampu účinok, minimálny efekt animácie, 
myši značky efekt, mierkav skutočnosti, screenshot efekt, list efekt, snímka 
efekt, posuvné vyskakovacie okná účinok,miniatúry na hlavnom paneli efekt, 
náhľad stranou efekt, priesvitnosť, translucencieúčinok, transparentnosť, okno 
geometrie efekt, vratkú okná efekt, uvedenie do prevádzkyspätná väzba, dialóg 
rodič efekt, matný efekt neaktívny, stlmiť obrazovku efekt,posunutím zadnej 
efekt, pastva pre oči, cukrík zobraziť FPS efekt, zobrazovať farby efekt, 
boxprepínač efekt, kryt prepínače účinok, desktop, desktop cube efekt kocky 
animácieúčinok, Desktop Grid efekt, flip switch efekt, obrys účinok, súčasné 
oknáúčinok, zmena veľkosti okna efekt
 X-KDE-Keywords[sl]=kwin,upravljalnik oken,učinek,učinki 3d,učinki 2d,grafični 
učinki,namizni učinki,animacije,upravljanje z okni,preklapljanje 
oken,preklapljanje namizij,namizne 
animacije,gonilniki,izrisovanje,obrni,povečevalno steklo,pripenjalni 
pomagalnik,sledenje miški,približanje,zabriši,eksplozija,pojemanje,pojemanje 
namizja,razpad,drsenje,poudari okno,učinek prijave,učinek odjave,čarobna 
svetilka,animacija skrčenja,risanje,animirano pojavljanje,zaslonska 
slika,list,drsenje,drseča pojavna okna,sličice za opravilno vrstico,sličica ob 
strani,prosojnost,prozornost,geometrija okna,majava okna,odziv zagona,nadrejeno 
pogovorno okno,potemni nedejavno,potemni zaslon,zdrs v ozadje,vidni 
bonbončki,pokaži sličice na sekundo,izrisovanje,preklapljanje - 
škatla,preklapljanje - ovitki,kocka z namizji,animacija kocka z namizji,mreža 
namizij,preklapljanje - sklad,oris,predstavi okna,spreminjanje velikosti okna
 X-KDE-Keywords[sr]=kwin,window,manager,effect,3D effects,2D effects,graphical 
effects,desktop effects,animations,various animations,window management 
effects,window switching effect,desktop switching effect,animations,desktop 
animations,drivers,driver settings,rendering,render,invert effect,looking glass 
effect,magnifier effect,snap helper effect,track mouse effect,zoom effect,blur 
effect,explosion effect,fade effect,fade desktop effect,fall apart effect,glide 
effect,highlight window effect,login effect,logout effect,magic lamp 
effect,minimize animation effect,mouse mark effect,scale in effect,screenshot 
effect,sheet effect,slide effect,sliding popups effect,taskbar thumbnails 
effect,thumbnail aside effect,translucency,translucency 
effect,transparency,window geometry effect,wobbly windows effect,startup 
feedback effect,dialog parent effect,dim inactive effect,dim screen 
effect,slide back effect,eye candy,candy,show FPS effect,show paint effect,box 
switch effect,cover switch effect,desktop cube effect,desktop cube animation 
effect,desktop grid effect,flip switch effect,outline effect,present windows 
effect,resize window effect,К‑вин,прозор,менаџер,ефекат,3Д ефекти,2Д 
ефекти,графички ефекти,ефекти површи,анимације,разне анимације,ефекти управљања 
прозорима,ефекти мењања прозора,ефекти мењања површи,анимације,анимације 
површи,драјвери,поставке драјвера,рендеровање,исцртавање,ефекат извртања,ефекат 
лупе,ефекат уклапања,ефекат праћења миша,ефекат увеличања,ефекат 
замућења,инструмент-табла,ефекат експлозије,ефекат утапања,ефеката утапања 
површи,ефекат распадања,ефекат распарчавања,ефекат клизања,ефекат истицања 
прозора,ефекат пријављивања,ефекат одјављивања,ефекат магичне лампе,ефекат 
минимизовања,ефекат трагова миша,ефекат скалирања,ефекат снимка екрана,ефекат 
листа,ефекат клизања,ефекат клизајућих искакача,ефекат ефекат сличица на траци 
задатака,ефекат прозирности,прозирност,провидност,ефекат геометрије 
прозора,ефекат лелујајућих прозора,ефекат одзива покретања,ефекат родитељског 
дијалог,ефекат потамњења неактивног,ефекат потамњења екрана,шминка,ефекат 
приказивања,ефекат кутијастог пребацивања,ефекат коцке површи,ефекат анимације 
коцке површи,ефекат мреже површи,ефекат превртања,ефекат представљања 
прозора,ефекат промене величине прозора
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' 
old/kwin-5.7.3/kcmkwin/kwincompositing/kwincompositing.desktop 
new/kwin-5.7.4/kcmkwin/kwincompositing/kwincompositing.desktop
--- old/kwin-5.7.3/kcmkwin/kwincompositing/kwincompositing.desktop      
2016-08-02 11:40:08.000000000 +0200
+++ new/kwin-5.7.4/kcmkwin/kwincompositing/kwincompositing.desktop      
2016-08-23 14:46:16.000000000 +0200
@@ -114,6 +114,7 @@
 X-KDE-Keywords[pl]=kwin,okno,menadżer,menedżer,zarządca,kompozytor,efekt,efekt 
3D,efekt 2D,OpenGL,XRender,ustawienia wideo,efekty graficzne,efekty 
pulpitu,szybkość animacji
 X-KDE-Keywords[pt]=kwin,janela,gestor,composição,efeito,efeitos 3D,efeitos 
2D,OpenGL,XRender,configuração do vídeo,efeitos gráficos,efeitos do 
ecrã,velocidade da animação
 X-KDE-Keywords[pt_BR]=kwin,janela,gerenciador,composição,efeito,efeitos 
3D,efeitos 2D,OpenGL,XRender,configurações de vídeo,efeitos gráficos,efeitos da 
área de trabalho,velocidade da animação
+X-KDE-Keywords[ru]=kwin,window,manager,compositing,effect,3D effects,2D 
effects,OpenGL,XRender,video settings,graphical effects,desktop 
effects,композитинг,композитный диспетчер окон,эффекты рабочего 
стола,графические эффекты,рендеринг,параметры видео,настройка видео,скорость 
анимации
 X-KDE-Keywords[sk]=kwin,okno,správca,kompozícia,efekt,3D efekty,2D 
efekty,OpenGL,XRender,nastavenia videa,grafické efekty,efekty plochy
 X-KDE-Keywords[sl]=kwin,okna,upravljalnik,skladnja,učinek,3D učinki,2D 
učinki,OpenGL,XRender,nastavitve videa,video,grafični učinki,učinki 
namizja,hitrost animacije
 X-KDE-Keywords[sr]=kwin,window,manager,compositing,effect,3D effects,2D 
effects,OpenGL,XRender,video settings,graphical effects,desktop 
effects,animation speed,К‑вин,прозор,менаџер,слагање,ефекти,3Д ефекти,2Д 
ефекти,опенГЛ,Икс‑рендер,видео поставке,графички ефекти,ефекти површи,брзина 
анимације
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/kcmkwin/kwintabbox/kwintabbox.desktop 
new/kwin-5.7.4/kcmkwin/kwintabbox/kwintabbox.desktop
--- old/kwin-5.7.3/kcmkwin/kwintabbox/kwintabbox.desktop        2016-08-02 
11:40:08.000000000 +0200
+++ new/kwin-5.7.4/kcmkwin/kwintabbox/kwintabbox.desktop        2016-08-23 
14:46:16.000000000 +0200
@@ -96,7 +96,7 @@
 Comment[nds]=Finstern dörgahn
 Comment[nl]=Navigatie door vensters
 Comment[nn]=Bla gjennom vindauge
-Comment[pl]=Przechodzenie pomiędzy oknami
+Comment[pl]=Przełączanie pomiędzy oknami
 Comment[pt]=Navegação pelas Janelas
 Comment[pt_BR]=Navegação pelas janelas
 Comment[ru]=Настройка переключателя окон
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/cs/kcmkwinrules.po 
new/kwin-5.7.4/po/cs/kcmkwinrules.po
--- old/kwin-5.7.3/po/cs/kcmkwinrules.po        2016-08-02 11:40:13.000000000 
+0200
+++ new/kwin-5.7.4/po/cs/kcmkwinrules.po        2016-08-23 14:46:33.000000000 
+0200
@@ -303,8 +303,8 @@
 
 #: ruleswidget.cpp:66
 msgid ""
-"Enable this checkbox to alter this window property for the specified "
-"window(s)."
+"Enable this checkbox to alter this window property for the specified window"
+"(s)."
 msgstr "Povolte ke změně této vlastnosti pro daná okna."
 
 #: ruleswidget.cpp:68
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/cs/kcmkwm.po 
new/kwin-5.7.4/po/cs/kcmkwm.po
--- old/kwin-5.7.3/po/cs/kcmkwm.po      2016-08-02 11:40:13.000000000 +0200
+++ new/kwin-5.7.4/po/cs/kcmkwm.po      2016-08-23 14:46:33.000000000 +0200
@@ -953,8 +953,8 @@
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiInAct2)
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiAct3)
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiInAct3)
-#: mouse.ui:75 mouse.ui:257 mouse.ui:330 mouse.ui:401 mouse.ui:474 mouse.ui:545
-#: mouse.ui:618
+#: mouse.ui:75 mouse.ui:257 mouse.ui:330 mouse.ui:401 mouse.ui:474
+#: mouse.ui:545 mouse.ui:618
 msgid "Shade"
 msgstr "Sbalit"
 
@@ -966,8 +966,8 @@
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiInAct2)
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiAct3)
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiInAct3)
-#: mouse.ui:85 mouse.ui:262 mouse.ui:335 mouse.ui:406 mouse.ui:479 mouse.ui:550
-#: mouse.ui:623
+#: mouse.ui:85 mouse.ui:262 mouse.ui:335 mouse.ui:406 mouse.ui:479
+#: mouse.ui:550 mouse.ui:623
 msgid "Close"
 msgstr "Zavřít"
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/cs/kwin.po new/kwin-5.7.4/po/cs/kwin.po
--- old/kwin-5.7.3/po/cs/kwin.po        2016-08-02 11:40:13.000000000 +0200
+++ new/kwin-5.7.4/po/cs/kwin.po        2016-08-23 14:46:33.000000000 +0200
@@ -9,7 +9,7 @@
 "Project-Id-Version: kwin\n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n";
 "POT-Creation-Date: 2016-07-21 11:58+0000\n"
-"PO-Revision-Date: 2016-07-21 16:18+0100\n"
+"PO-Revision-Date: 2016-08-17 14:27+0100\n"
 "Last-Translator: Vít Pelčák <v...@pelcak.org>\n"
 "Language-Team: Czech <kde-i18n-...@kde.org>\n"
 "Language: cs\n"
@@ -75,107 +75,107 @@
 #: debug_console.cpp:85
 msgctxt "A mouse button"
 msgid "Extra Button 4"
-msgstr ""
+msgstr "Extra tlačítko 4"
 
 #: debug_console.cpp:87
 msgctxt "A mouse button"
 msgid "Extra Button 5"
-msgstr ""
+msgstr "Extra tlačítko 5"
 
 #: debug_console.cpp:89
 msgctxt "A mouse button"
 msgid "Extra Button 6"
-msgstr ""
+msgstr "Extra tlačítko 6"
 
 #: debug_console.cpp:91
 msgctxt "A mouse button"
 msgid "Extra Button 7"
-msgstr ""
+msgstr "Extra tlačítko 7"
 
 #: debug_console.cpp:93
 msgctxt "A mouse button"
 msgid "Extra Button 8"
-msgstr ""
+msgstr "Extra tlačítko 8"
 
 #: debug_console.cpp:95
 msgctxt "A mouse button"
 msgid "Extra Button 9"
-msgstr ""
+msgstr "Extra tlačítko 9"
 
 #: debug_console.cpp:97
 msgctxt "A mouse button"
 msgid "Extra Button 10"
-msgstr ""
+msgstr "Extra tlačítko 10"
 
 #: debug_console.cpp:99
 msgctxt "A mouse button"
 msgid "Extra Button 11"
-msgstr ""
+msgstr "Extra tlačítko 11"
 
 #: debug_console.cpp:101
 msgctxt "A mouse button"
 msgid "Extra Button 12"
-msgstr ""
+msgstr "Extra tlačítko 12"
 
 #: debug_console.cpp:103
 msgctxt "A mouse button"
 msgid "Extra Button 13"
-msgstr ""
+msgstr "Extra tlačítko 13"
 
 #: debug_console.cpp:105
 msgctxt "A mouse button"
 msgid "Extra Button 14"
-msgstr ""
+msgstr "Extra tlačítko 14"
 
 #: debug_console.cpp:107
 msgctxt "A mouse button"
 msgid "Extra Button 15"
-msgstr ""
+msgstr "Extra tlačítko 15"
 
 #: debug_console.cpp:109
 msgctxt "A mouse button"
 msgid "Extra Button 16"
-msgstr ""
+msgstr "Extra tlačítko 16"
 
 #: debug_console.cpp:111
 msgctxt "A mouse button"
 msgid "Extra Button 17"
-msgstr ""
+msgstr "Extra tlačítko 17"
 
 #: debug_console.cpp:113
 msgctxt "A mouse button"
 msgid "Extra Button 18"
-msgstr ""
+msgstr "Extra tlačítko 18"
 
 #: debug_console.cpp:115
 msgctxt "A mouse button"
 msgid "Extra Button 19"
-msgstr ""
+msgstr "Extra tlačítko 19"
 
 #: debug_console.cpp:117
 msgctxt "A mouse button"
 msgid "Extra Button 20"
-msgstr ""
+msgstr "Extra tlačítko 20"
 
 #: debug_console.cpp:119
 msgctxt "A mouse button"
 msgid "Extra Button 21"
-msgstr ""
+msgstr "Extra tlačítko 21"
 
 #: debug_console.cpp:121
 msgctxt "A mouse button"
 msgid "Extra Button 22"
-msgstr ""
+msgstr "Extra tlačítko 22"
 
 #: debug_console.cpp:123
 msgctxt "A mouse button"
 msgid "Extra Button 23"
-msgstr ""
+msgstr "Extra tlačítko 23"
 
 #: debug_console.cpp:125
 msgctxt "A mouse button"
 msgid "Extra Button 24"
-msgstr ""
+msgstr "Extra tlačítko 24"
 
 #: debug_console.cpp:135 debug_console.cpp:137
 msgid "Input Device"
@@ -204,7 +204,7 @@
 #: debug_console.cpp:186 debug_console.cpp:196
 msgctxt "A button in a mouse press/release event"
 msgid "Button"
-msgstr ""
+msgstr "Tlačítko"
 
 #: debug_console.cpp:187 debug_console.cpp:197
 msgctxt "A button in a mouse press/release event"
@@ -229,27 +229,27 @@
 #: debug_console.cpp:220
 msgctxt "The orientation of a pointer axis event"
 msgid "Orientation"
-msgstr ""
+msgstr "7Natočení"
 
 #: debug_console.cpp:221
 msgctxt "An orientation of a pointer axis event"
 msgid "Horizontal"
-msgstr ""
+msgstr "Vodorovně"
 
 #: debug_console.cpp:222
 msgctxt "An orientation of a pointer axis event"
 msgid "Vertical"
-msgstr ""
+msgstr "Svisle"
 
 #: debug_console.cpp:238
 msgctxt "A key press event"
 msgid "Key Press"
-msgstr ""
+msgstr "Stisk klávesy"
 
 #: debug_console.cpp:241
 msgctxt "A key release event"
 msgid "Key Release"
-msgstr ""
+msgstr "Uvolnění klávesy"
 
 #: debug_console.cpp:252
 msgctxt "A keyboard modifier"
@@ -284,7 +284,7 @@
 #: debug_console.cpp:278
 msgctxt "Whether the event is an automatic key repeat"
 msgid "Repeat"
-msgstr ""
+msgstr "Opakovat"
 
 #: debug_console.cpp:279
 msgctxt "The code as read from the input device"
@@ -294,7 +294,7 @@
 #: debug_console.cpp:280
 msgctxt "The translated code to an Xkb symbol"
 msgid "Xkb symbol"
-msgstr ""
+msgstr "Symbol Xkb"
 
 #: debug_console.cpp:281
 msgctxt "The translated code interpreted as text"
@@ -304,7 +304,7 @@
 #: debug_console.cpp:282
 msgctxt "The currently active modifiers"
 msgid "Modifiers"
-msgstr ""
+msgstr "Modifikátory"
 
 #: debug_console.cpp:295
 msgctxt "A touch down event"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/cs/kwin_effects.po 
new/kwin-5.7.4/po/cs/kwin_effects.po
--- old/kwin-5.7.3/po/cs/kwin_effects.po        2016-08-02 11:40:13.000000000 
+0200
+++ new/kwin-5.7.4/po/cs/kwin_effects.po        2016-08-23 14:46:33.000000000 
+0200
@@ -168,7 +168,7 @@
 #: trackmouse/trackmouse_config.cpp:62
 #: windowgeometry/windowgeometry_config.cpp:54 zoom/zoom_config.cpp:63
 msgid "KWin"
-msgstr ""
+msgstr "KWin"
 
 #. i18n: ectx: attribute (title), widget (QWidget, tab)
 #: cube/cube_config.ui:21
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/en_GB/kcmkwinscreenedges.po 
new/kwin-5.7.4/po/en_GB/kcmkwinscreenedges.po
--- old/kwin-5.7.3/po/en_GB/kcmkwinscreenedges.po       2016-08-02 
11:40:15.000000000 +0200
+++ new/kwin-5.7.4/po/en_GB/kcmkwinscreenedges.po       2016-08-23 
14:46:42.000000000 +0200
@@ -2,20 +2,21 @@
 # This file is distributed under the same license as the PACKAGE package.
 #
 # Andrew Coles <andrew_co...@yahoo.co.uk>, 2009, 2010.
-# Steve Allewell <steve.allew...@gmail.com>, 2014.
+# Steve Allewell <steve.allew...@gmail.com>, 2014, 2016.
 msgid ""
 msgstr ""
 "Project-Id-Version: kcmkwinscreenedges\n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n";
 "POT-Creation-Date: 2016-05-09 08:35+0000\n"
-"PO-Revision-Date: 2014-06-28 18:06+0100\n"
+"PO-Revision-Date: 2016-08-05 13:10+0000\n"
 "Last-Translator: Steve Allewell <steve.allew...@gmail.com>\n"
-"Language-Team: British English <kde-l10n-en...@kde.org>\n"
+"Language-Team: English <kde-l10n-en...@kde.org>\n"
 "Language: en_GB\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
+"X-Generator: Lokalize 2.0\n"
 
 msgctxt "NAME OF TRANSLATORS"
 msgid "Your names"
@@ -40,11 +41,11 @@
 #: main.cpp:190
 msgctxt "Open krunner"
 msgid "Run Command"
-msgstr ""
+msgstr "Run Command"
 
 #: main.cpp:191
 msgid "Activity Manager"
-msgstr ""
+msgstr "Activity Manager"
 
 #: main.cpp:195
 #, kde-format
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/en_GB/kwin.po 
new/kwin-5.7.4/po/en_GB/kwin.po
--- old/kwin-5.7.3/po/en_GB/kwin.po     2016-08-02 11:40:15.000000000 +0200
+++ new/kwin-5.7.4/po/en_GB/kwin.po     2016-08-23 14:46:42.000000000 +0200
@@ -9,15 +9,15 @@
 "Project-Id-Version: kwin\n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n";
 "POT-Creation-Date: 2016-07-21 11:58+0000\n"
-"PO-Revision-Date: 2016-04-24 11:20+0100\n"
+"PO-Revision-Date: 2016-08-05 13:10+0000\n"
 "Last-Translator: Steve Allewell <steve.allew...@gmail.com>\n"
-"Language-Team: British English <kde-l10n-en...@kde.org>\n"
+"Language-Team: English <kde-l10n-en...@kde.org>\n"
 "Language: en_GB\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Generator: Lokalize 1.5\n"
+"X-Generator: Lokalize 2.0\n"
 
 msgctxt "NAME OF TRANSLATORS"
 msgid "Your names"
@@ -179,12 +179,12 @@
 
 #: debug_console.cpp:135 debug_console.cpp:137
 msgid "Input Device"
-msgstr ""
+msgstr "Input Device"
 
 #: debug_console.cpp:135
 msgctxt "The input device of the event is not known"
 msgid "Unknown"
-msgstr ""
+msgstr "Unknown"
 
 #: debug_console.cpp:173
 msgctxt "A mouse pointer motion event"
@@ -332,214 +332,158 @@
 msgstr "Touch Up"
 
 #: debug_console.cpp:421
-#, fuzzy
-#| msgid "Mouse Emulation"
 msgid "No Mouse Buttons"
-msgstr "Mouse Emulation"
+msgstr "No Mouse Buttons"
 
 #: debug_console.cpp:425
 msgctxt "Mouse Button"
 msgid "left"
-msgstr ""
+msgstr "left"
 
 #: debug_console.cpp:428
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Right"
 msgctxt "Mouse Button"
 msgid "right"
-msgstr "Right"
+msgstr "right"
 
 #: debug_console.cpp:431
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Middle"
 msgctxt "Mouse Button"
 msgid "middle"
-msgstr "Middle"
+msgstr "middle"
 
 #: debug_console.cpp:434
 msgctxt "Mouse Button"
 msgid "back"
-msgstr ""
+msgstr "back"
 
 #: debug_console.cpp:437
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Forward"
 msgctxt "Mouse Button"
 msgid "forward"
-msgstr "Forward"
+msgstr "forward"
 
 #: debug_console.cpp:440
 msgctxt "Mouse Button"
 msgid "extra 1"
-msgstr ""
+msgstr "extra 1"
 
 #: debug_console.cpp:443
 msgctxt "Mouse Button"
 msgid "extra 2"
-msgstr ""
+msgstr "extra 2"
 
 #: debug_console.cpp:446
 msgctxt "Mouse Button"
 msgid "extra 3"
-msgstr ""
+msgstr "extra 3"
 
 #: debug_console.cpp:449
 msgctxt "Mouse Button"
 msgid "extra 4"
-msgstr ""
+msgstr "extra 4"
 
 #: debug_console.cpp:452
 msgctxt "Mouse Button"
 msgid "extra 5"
-msgstr ""
+msgstr "extra 5"
 
 #: debug_console.cpp:455
 msgctxt "Mouse Button"
 msgid "extra 6"
-msgstr ""
+msgstr "extra 6"
 
 #: debug_console.cpp:458
 msgctxt "Mouse Button"
 msgid "extra 7"
-msgstr ""
+msgstr "extra 7"
 
 #: debug_console.cpp:461
 msgctxt "Mouse Button"
 msgid "extra 8"
-msgstr ""
+msgstr "extra 8"
 
 #: debug_console.cpp:464
 msgctxt "Mouse Button"
 msgid "extra 9"
-msgstr ""
+msgstr "extra 9"
 
 #: debug_console.cpp:467
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 10"
 msgctxt "Mouse Button"
 msgid "extra 10"
-msgstr "Extra Button 10"
+msgstr "extra 10"
 
 #: debug_console.cpp:470
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 11"
 msgctxt "Mouse Button"
 msgid "extra 11"
-msgstr "Extra Button 11"
+msgstr "extra 11"
 
 #: debug_console.cpp:473
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 12"
 msgctxt "Mouse Button"
 msgid "extra 12"
-msgstr "Extra Button 12"
+msgstr "extra 12"
 
 #: debug_console.cpp:476
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 13"
 msgctxt "Mouse Button"
 msgid "extra 13"
-msgstr "Extra Button 13"
+msgstr "extra 13"
 
 #: debug_console.cpp:479
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 14"
 msgctxt "Mouse Button"
 msgid "extra 14"
-msgstr "Extra Button 14"
+msgstr "extra 14"
 
 #: debug_console.cpp:482
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 15"
 msgctxt "Mouse Button"
 msgid "extra 15"
-msgstr "Extra Button 15"
+msgstr "extra 15"
 
 #: debug_console.cpp:485
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 16"
 msgctxt "Mouse Button"
 msgid "extra 16"
-msgstr "Extra Button 16"
+msgstr "extra 16"
 
 #: debug_console.cpp:488
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 17"
 msgctxt "Mouse Button"
 msgid "extra 17"
-msgstr "Extra Button 17"
+msgstr "extra 17"
 
 #: debug_console.cpp:491
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 18"
 msgctxt "Mouse Button"
 msgid "extra 18"
-msgstr "Extra Button 18"
+msgstr "extra 18"
 
 #: debug_console.cpp:494
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 19"
 msgctxt "Mouse Button"
 msgid "extra 19"
-msgstr "Extra Button 19"
+msgstr "extra 19"
 
 #: debug_console.cpp:497
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 20"
 msgctxt "Mouse Button"
 msgid "extra 20"
-msgstr "Extra Button 20"
+msgstr "extra 20"
 
 #: debug_console.cpp:500
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 21"
 msgctxt "Mouse Button"
 msgid "extra 21"
-msgstr "Extra Button 21"
+msgstr "extra 21"
 
 #: debug_console.cpp:503
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 22"
 msgctxt "Mouse Button"
 msgid "extra 22"
-msgstr "Extra Button 22"
+msgstr "extra 22"
 
 #: debug_console.cpp:506
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 23"
 msgctxt "Mouse Button"
 msgid "extra 23"
-msgstr "Extra Button 23"
+msgstr "extra 23"
 
 #: debug_console.cpp:509
-#, fuzzy
-#| msgctxt "A mouse button"
-#| msgid "Extra Button 24"
 msgctxt "Mouse Button"
 msgid "extra 24"
-msgstr "Extra Button 24"
+msgstr "extra 24"
 
 #: debug_console.cpp:512
 msgctxt "Mouse Button"
 msgid "task"
-msgstr ""
+msgstr "task"
 
 #: debug_console.cpp:853
 msgid "X11 Client Windows"
@@ -1454,15 +1398,15 @@
 
 #: virtualkeyboard.cpp:92
 msgid "Virtual Keyboard"
-msgstr ""
+msgstr "Virtual Keyboard"
 
 #: virtualkeyboard.cpp:208
 msgid "Virtual Keyboard is enabled."
-msgstr ""
+msgstr "Virtual Keyboard is enabled."
 
 #: virtualkeyboard.cpp:211
 msgid "Virtual Keyboard is disabled."
-msgstr ""
+msgstr "Virtual Keyboard is disabled."
 
 #: workspace.cpp:1320
 msgctxt "Introductory text shown in the support information."
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/ja/kcmkwinrules.po 
new/kwin-5.7.4/po/ja/kcmkwinrules.po
--- old/kwin-5.7.3/po/ja/kcmkwinrules.po        2016-08-02 11:40:24.000000000 
+0200
+++ new/kwin-5.7.4/po/ja/kcmkwinrules.po        2016-08-23 14:46:52.000000000 
+0200
@@ -301,8 +301,8 @@
 
 #: ruleswidget.cpp:66
 msgid ""
-"Enable this checkbox to alter this window property for the specified "
-"window(s)."
+"Enable this checkbox to alter this window property for the specified window"
+"(s)."
 msgstr ""
 "特定のウィンドウについてウィンドウのプロパティを変更するには、該当する項目に"
 "チェックを入れてください。"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/ja/kcmkwm.po 
new/kwin-5.7.4/po/ja/kcmkwm.po
--- old/kwin-5.7.3/po/ja/kcmkwm.po      2016-08-02 11:40:24.000000000 +0200
+++ new/kwin-5.7.4/po/ja/kcmkwm.po      2016-08-23 14:46:52.000000000 +0200
@@ -1059,8 +1059,8 @@
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiInAct2)
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiAct3)
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiInAct3)
-#: mouse.ui:75 mouse.ui:257 mouse.ui:330 mouse.ui:401 mouse.ui:474 mouse.ui:545
-#: mouse.ui:618
+#: mouse.ui:75 mouse.ui:257 mouse.ui:330 mouse.ui:401 mouse.ui:474
+#: mouse.ui:545 mouse.ui:618
 msgid "Shade"
 msgstr "シェード"
 
@@ -1072,8 +1072,8 @@
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiInAct2)
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiAct3)
 #. i18n: ectx: property (text), item, widget (KComboBox, coTiInAct3)
-#: mouse.ui:85 mouse.ui:262 mouse.ui:335 mouse.ui:406 mouse.ui:479 mouse.ui:550
-#: mouse.ui:623
+#: mouse.ui:85 mouse.ui:262 mouse.ui:335 mouse.ui:406 mouse.ui:479
+#: mouse.ui:550 mouse.ui:623
 msgid "Close"
 msgstr "閉じる"
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/pl/kcmkwincompositing.po 
new/kwin-5.7.4/po/pl/kcmkwincompositing.po
--- old/kwin-5.7.3/po/pl/kcmkwincompositing.po  2016-08-02 11:40:33.000000000 
+0200
+++ new/kwin-5.7.4/po/pl/kcmkwincompositing.po  2016-08-23 14:47:03.000000000 
+0200
@@ -11,7 +11,7 @@
 "Project-Id-Version: kcmkwincompositing\n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n";
 "POT-Creation-Date: 2016-07-21 11:58+0000\n"
-"PO-Revision-Date: 2016-07-02 08:21+0100\n"
+"PO-Revision-Date: 2016-08-20 08:25+0100\n"
 "Last-Translator: Łukasz Wojniłowicz <lukasz.wojnilow...@gmail.com>\n"
 "Language-Team: Polish <kde-i18n-...@kde.org>\n"
 "Language: pl\n"
@@ -62,12 +62,12 @@
 "immediate crash!\n"
 "Alternatively, you might want to use the XRender backend instead."
 msgstr ""
-"Kompozycje OpenGL (domyślne) spowodowały awarię KWin w przeszłości.\n"
-"Z dużą pewnością stało się tak z powodu błędu w sterowniku.\n"
-"Jeśli od tamtego czasu nastąpiło uaktualnienie do stabilnego sterowniki,\n"
-"to można wyzerować to ostrzeżenie, lecz licz się z tym, że może oznaczać to "
-"natychmiastową awarię!\n"
-"Alternatywnie, można użyć silnika XRender."
+"Kompozycje OpenGL wywołały usterkę KWin w przeszłości.\n"
+"Najprawdopodobniej powodem był błąd w sterowniku.\n"
+"Włącz wykrywanie OpenGL, gdy uważasz, że w międzyczasie,\n"
+"uaktualniłeś sterowniki do bardziej stabilnych, jednak miej na uwadze, że "
+"może to natychmiastowo wywołać usterkę!\n"
+"Alternatywnie, możesz użyć silnika XRender."
 
 #. i18n: ectx: property (text), widget (KMessageWidget, scaleWarning)
 #: compositing.ui:45
@@ -218,7 +218,7 @@
 
 #: main.cpp:82
 msgid "Re-enable OpenGL detection"
-msgstr "Włącz ponownie wykrywanie OpenGL"
+msgstr "Włącz wykrywanie OpenGL"
 
 #: main.cpp:138
 msgid ""
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/pl/kwin.po new/kwin-5.7.4/po/pl/kwin.po
--- old/kwin-5.7.3/po/pl/kwin.po        2016-08-02 11:40:33.000000000 +0200
+++ new/kwin-5.7.4/po/pl/kwin.po        2016-08-23 14:47:03.000000000 +0200
@@ -1,5 +1,5 @@
 # translation of kwin.po to
-# Version: $Revision: 1465027 $
+# Version: $Revision: 1466653 $
 # translation of kwin.po to Polish
 # translation of kwin.po to
 # Norbert Popiołek <norb...@kde.com.pl>
@@ -16,7 +16,7 @@
 "Project-Id-Version: kwin\n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n";
 "POT-Creation-Date: 2016-07-21 11:58+0000\n"
-"PO-Revision-Date: 2016-07-16 08:58+0100\n"
+"PO-Revision-Date: 2016-08-06 07:31+0100\n"
 "Last-Translator: Łukasz Wojniłowicz <lukasz.wojnilow...@gmail.com>\n"
 "Language-Team: Polish <kde-i18n-...@kde.org>\n"
 "Language: pl\n"
@@ -625,11 +625,11 @@
 
 #: kwinbindings.cpp:40
 msgid "Walk Through Window Tabs"
-msgstr "Przechodzenie między kartami"
+msgstr "Przełącz kartę okna"
 
 #: kwinbindings.cpp:41
 msgid "Walk Through Window Tabs (Reverse)"
-msgstr "Przechodzenie między kartami (odwrotne)"
+msgstr "Przełącz kartę okna (odwrotnie)"
 
 #: kwinbindings.cpp:42
 msgid "Remove Window From Group"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/ru/kcmkwinrules.po 
new/kwin-5.7.4/po/ru/kcmkwinrules.po
--- old/kwin-5.7.3/po/ru/kcmkwinrules.po        2016-08-02 11:40:35.000000000 
+0200
+++ new/kwin-5.7.4/po/ru/kcmkwinrules.po        2016-08-23 14:47:06.000000000 
+0200
@@ -4,7 +4,7 @@
 # Gregory Mokhin <m...@kde.ru>, 2005.
 # Leonid Kanter <l...@asplinux.ru>, 2005.
 # Andrey Cherepanov <sk...@kde.ru>, 2009.
-# Alexander Potashev <aspotas...@gmail.com>, 2010, 2011, 2012, 2014, 2015.
+# Alexander Potashev <aspotas...@gmail.com>, 2010, 2011, 2012, 2014, 2015, 
2016.
 # Alexey D. <lq07829ic...@rambler.ru>, 2012.
 # Yuri Efremov <yur....@gmail.com>, 2012, 2013.
 # Alexander Lakhin <exclus...@gmail.com>, 2013.
@@ -13,7 +13,7 @@
 "Project-Id-Version: kcmkwinrules\n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n";
 "POT-Creation-Date: 2015-11-19 09:30+0000\n"
-"PO-Revision-Date: 2015-04-18 21:08+0300\n"
+"PO-Revision-Date: 2016-08-13 22:01+0300\n"
 "Last-Translator: Alexander Potashev <aspotas...@gmail.com>\n"
 "Language-Team: Russian <kde-russ...@lists.kde.ru>\n"
 "Language: ru\n"
@@ -1093,13 +1093,20 @@
 "Otherwise it's interleaved with the stealing prevention\n"
 "assigned to the window that wants the focus."
 msgstr ""
+"Этот параметр определяет приоритет, с которым текущее окно\n"
+"старается удерживать фокус.\n"
+"\n"
+"«Отключить» позволит отдавать фокус всегда.\n"
+"«Не передавать фокус автоматически» запрещает\n"
+"передачу фокуса другому окну.\n"
+"При промежуточных значениях этого параметра будет\n"
+"также учитываться параметр «Предотвращение похищения\n"
+"фокуса» у окна, которое запрашивает фокус."
 
 #. i18n: ectx: property (text), widget (QCheckBox, enable_fpplevel)
 #: ruleswidgetbase.ui:2232
-#, fuzzy
-#| msgid "&Focus stealing prevention"
 msgid "Focus protection"
-msgstr "Предотвращение похищения &фокуса"
+msgstr "Защита фокуса"
 
 #. i18n: ectx: property (toolTip), widget (QCheckBox, enable_acceptfocus)
 #: ruleswidgetbase.ui:2295
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/ru/kcmkwinscreenedges.po 
new/kwin-5.7.4/po/ru/kcmkwinscreenedges.po
--- old/kwin-5.7.3/po/ru/kcmkwinscreenedges.po  2016-08-02 11:40:35.000000000 
+0200
+++ new/kwin-5.7.4/po/ru/kcmkwinscreenedges.po  2016-08-23 14:47:06.000000000 
+0200
@@ -1,7 +1,7 @@
 # Copyright (C) YEAR This_file_is_part_of_KDE
 # This file is distributed under the same license as the PACKAGE package.
 #
-# Alexander Potashev <aspotas...@gmail.com>, 2009, 2010, 2014.
+# Alexander Potashev <aspotas...@gmail.com>, 2009, 2010, 2014, 2016.
 # Nick Shaforostoff <shaforost...@kde.ru>, 2009.
 # Nick Shaforostoff <sha...@ukr.net>, 2009, 2010.
 # Andrey Cherepanov <sk...@kde.ru>, 2009.
@@ -12,14 +12,14 @@
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n";
 "POT-Creation-Date: 2016-05-09 08:35+0000\n"
-"PO-Revision-Date: 2014-08-26 13:20+0400\n"
+"PO-Revision-Date: 2016-08-13 21:48+0300\n"
 "Last-Translator: Alexander Potashev <aspotas...@gmail.com>\n"
 "Language-Team: Russian <kde-russ...@lists.kde.ru>\n"
 "Language: ru\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 1.5\n"
+"X-Generator: Lokalize 2.0\n"
 "Plural-Forms: nplurals=4; plural=n==1 ? 3 : n%10==1 && n%100!=11 ? 0 : n"
 "%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
 "X-Environment: kde\n"
@@ -49,11 +49,11 @@
 #: main.cpp:190
 msgctxt "Open krunner"
 msgid "Run Command"
-msgstr ""
+msgstr "Выполнить команду"
 
 #: main.cpp:191
 msgid "Activity Manager"
-msgstr ""
+msgstr "Диспетчер комнат"
 
 #: main.cpp:195
 #, kde-format
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/po/ru/kwin.po new/kwin-5.7.4/po/ru/kwin.po
--- old/kwin-5.7.3/po/ru/kwin.po        2016-08-02 11:40:35.000000000 +0200
+++ new/kwin-5.7.4/po/ru/kwin.po        2016-08-23 14:47:06.000000000 +0200
@@ -20,7 +20,7 @@
 "Project-Id-Version: kwin\n"
 "Report-Msgid-Bugs-To: http://bugs.kde.org\n";
 "POT-Creation-Date: 2016-07-21 11:58+0000\n"
-"PO-Revision-Date: 2016-06-30 10:51+0300\n"
+"PO-Revision-Date: 2016-08-23 01:57+0300\n"
 "Last-Translator: Alexander Potashev <aspotas...@gmail.com>\n"
 "Language-Team: Russian <kde-russ...@lists.kde.ru>\n"
 "Language: ru\n"
@@ -52,9 +52,10 @@
 "Графические эффекты были отключены другим приложением.<br/>Можно их "
 "возобновить комбинацией клавиш «%1»."
 
+# BUGME: strings from kwin.git/debug_console.ui are not translatable 
--aspotashev
 #: debug_console.cpp:66
 msgid "Timestamp"
-msgstr ""
+msgstr "Временная метка"
 
 #: debug_console.cpp:73
 msgctxt "A mouse button"
@@ -193,22 +194,22 @@
 
 #: debug_console.cpp:135 debug_console.cpp:137
 msgid "Input Device"
-msgstr ""
+msgstr "Устройство ввода"
 
 #: debug_console.cpp:135
 msgctxt "The input device of the event is not known"
 msgid "Unknown"
-msgstr ""
+msgstr "Неизвестное"
 
 #: debug_console.cpp:173
 msgctxt "A mouse pointer motion event"
 msgid "Pointer Motion"
-msgstr ""
+msgstr "Движение указателя"
 
 #: debug_console.cpp:178
 msgctxt "The global mouse pointer position"
 msgid "Global Position"
-msgstr ""
+msgstr "Абсолютное положение"
 
 #: debug_console.cpp:181
 msgctxt "A mouse pointer button press event"
@@ -258,12 +259,12 @@
 #: debug_console.cpp:238
 msgctxt "A key press event"
 msgid "Key Press"
-msgstr ""
+msgstr "Нажатие клавиши"
 
 #: debug_console.cpp:241
 msgctxt "A key release event"
 msgid "Key Release"
-msgstr ""
+msgstr "Отпускание клавиши"
 
 #: debug_console.cpp:252
 msgctxt "A keyboard modifier"
@@ -288,68 +289,66 @@
 #: debug_console.cpp:268
 msgctxt "A keyboard modifier"
 msgid "Keypad"
-msgstr ""
+msgstr "Дополнительная клавиатура"
 
 #: debug_console.cpp:272
 msgctxt "A keyboard modifier"
 msgid "Group-switch"
-msgstr ""
+msgstr "Групповой переключатель"
 
 #: debug_console.cpp:278
 msgctxt "Whether the event is an automatic key repeat"
 msgid "Repeat"
-msgstr ""
+msgstr "Автоповтор"
 
 #: debug_console.cpp:279
 msgctxt "The code as read from the input device"
 msgid "Scan code"
-msgstr ""
+msgstr "Скан-код"
 
 #: debug_console.cpp:280
 msgctxt "The translated code to an Xkb symbol"
 msgid "Xkb symbol"
-msgstr ""
+msgstr "Символ XKB"
 
 #: debug_console.cpp:281
 msgctxt "The translated code interpreted as text"
 msgid "Utf8"
-msgstr ""
+msgstr "UTF-8"
 
 #: debug_console.cpp:282
 msgctxt "The currently active modifiers"
 msgid "Modifiers"
-msgstr ""
+msgstr "Клавиши-модификаторы"
 
 #: debug_console.cpp:295
 msgctxt "A touch down event"
 msgid "Touch down"
-msgstr ""
+msgstr "Прикосновение"
 
 #: debug_console.cpp:297 debug_console.cpp:313 debug_console.cpp:329
 msgctxt "The id of the touch point in the touch event"
 msgid "Point identifier"
-msgstr ""
+msgstr "Идентификатор точки"
 
 #: debug_console.cpp:298 debug_console.cpp:314
 msgctxt "The global position of the touch point"
 msgid "Global position"
-msgstr ""
+msgstr "Абсолютное положение"
 
 #: debug_console.cpp:311
 msgctxt "A touch motion event"
 msgid "Touch Motion"
-msgstr ""
+msgstr "Движение точки касания"
 
 #: debug_console.cpp:327
 msgctxt "A touch up event"
 msgid "Touch Up"
-msgstr ""
+msgstr "Отпускание панели"
 
 #: debug_console.cpp:421
-#, fuzzy
-#| msgid "Mouse Emulation"
 msgid "No Mouse Buttons"
-msgstr "Эмуляция мыши"
+msgstr "Нет кнопок мыши"
 
 #: debug_console.cpp:425
 msgctxt "Mouse Button"
@@ -502,26 +501,20 @@
 msgstr "задача"
 
 #: debug_console.cpp:853
-#, fuzzy
-#| msgid "Close Window"
 msgid "X11 Client Windows"
-msgstr "Закрыть окно"
+msgstr "Окна клиентов X11"
 
 #: debug_console.cpp:855
 msgid "X11 Unmanaged Windows"
-msgstr ""
+msgstr "Неуправляемые окна X11"
 
 #: debug_console.cpp:857
-#, fuzzy
-#| msgid "Shade Window"
 msgid "Wayland Windows"
-msgstr "Свернуть окно в заголовок"
+msgstr "Окна Wayland"
 
 #: debug_console.cpp:859
-#, fuzzy
-#| msgid "Lower Window"
 msgid "Internal Windows"
-msgstr "Опустить окно"
+msgstr "Внутренние окна"
 
 #: killer/killer.cpp:44
 msgid "Window Manager"
@@ -1007,7 +1000,7 @@
 
 #: main_wayland.cpp:593 main_x11.cpp:423
 msgid "Disable KActivities integration."
-msgstr ""
+msgstr "Выключить интеграцию с комнатами KDE."
 
 #: main_wayland.cpp:598
 msgid "Applications to start once Wayland and Xwayland server are started"
@@ -1427,15 +1420,15 @@
 
 #: virtualkeyboard.cpp:92
 msgid "Virtual Keyboard"
-msgstr ""
+msgstr "Виртуальная клавиатура"
 
 #: virtualkeyboard.cpp:208
 msgid "Virtual Keyboard is enabled."
-msgstr ""
+msgstr "Экранная клавиатура включена."
 
 #: virtualkeyboard.cpp:211
 msgid "Virtual Keyboard is disabled."
-msgstr ""
+msgstr "Экранная клавиатура выключена."
 
 #: workspace.cpp:1320
 msgctxt "Introductory text shown in the support information."
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/pointer_input.cpp 
new/kwin-5.7.4/pointer_input.cpp
--- old/kwin-5.7.3/pointer_input.cpp    2016-08-02 11:40:08.000000000 +0200
+++ new/kwin-5.7.4/pointer_input.cpp    2016-08-23 14:46:16.000000000 +0200
@@ -281,6 +281,9 @@
     }
     if (t && t->surface()) {
         m_window = QPointer<Toplevel>(t);
+        // TODO: add convenient API to update global pos together with 
updating focused surface
+        seat->setFocusedPointerSurface(nullptr);
+        seat->setPointerPos(m_pos.toPoint());
         seat->setFocusedPointerSurface(t->surface(), t->inputTransformation());
         m_windowGeometryConnection = connect(t, &Toplevel::geometryChanged, 
this,
             [this] {
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/scene.cpp new/kwin-5.7.4/scene.cpp
--- old/kwin-5.7.3/scene.cpp    2016-08-02 11:40:08.000000000 +0200
+++ new/kwin-5.7.4/scene.cpp    2016-08-23 14:46:16.000000000 +0200
@@ -928,6 +928,15 @@
     return ret;
 }
 
+void Scene::Window::updateShadow(Shadow* shadow)
+{
+    if (m_shadow == shadow) {
+        return;
+    }
+    delete m_shadow;
+    m_shadow = shadow;
+}
+
 //****************************************
 // WindowPixmap
 //****************************************
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/scene.h new/kwin-5.7.4/scene.h
--- old/kwin-5.7.3/scene.h      2016-08-02 11:40:08.000000000 +0200
+++ new/kwin-5.7.4/scene.h      2016-08-23 14:46:16.000000000 +0200
@@ -538,12 +538,6 @@
 }
 
 inline
-void Scene::Window::updateShadow(Shadow* shadow)
-{
-    m_shadow = shadow;
-}
-
-inline
 const Shadow* Scene::Window::shadow() const
 {
     return m_shadow;
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/shadow.cpp new/kwin-5.7.4/shadow.cpp
--- old/kwin-5.7.3/shadow.cpp   2016-08-02 11:40:08.000000000 +0200
+++ new/kwin-5.7.4/shadow.cpp   2016-08-23 14:46:16.000000000 +0200
@@ -337,10 +337,11 @@
     auto clear = [this]() {
         if (m_topLevel && m_topLevel->effectWindow() && 
m_topLevel->effectWindow()->sceneWindow() &&
                                             
m_topLevel->effectWindow()->sceneWindow()->shadow()) {
-            m_topLevel->effectWindow()->sceneWindow()->updateShadow(0);
-            m_topLevel->effectWindow()->buildQuads(true);
+            auto w = m_topLevel->effectWindow();
+            // this also deletes the shadow
+            w->sceneWindow()->updateShadow(nullptr);
+            w->buildQuads(true);
         }
-        deleteLater();
     };
     if (m_decorationShadow) {
         if (AbstractClient *c = qobject_cast<AbstractClient*>(m_topLevel)) {
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/x11eventfilter.cpp 
new/kwin-5.7.4/x11eventfilter.cpp
--- old/kwin-5.7.3/x11eventfilter.cpp   2016-08-02 11:40:08.000000000 +0200
+++ new/kwin-5.7.4/x11eventfilter.cpp   2016-08-23 14:46:16.000000000 +0200
@@ -25,7 +25,12 @@
 {
 
 X11EventFilter::X11EventFilter(int eventType, int opcode, int genericEventType)
-    : m_eventType(eventType), m_extension(opcode), 
m_genericEventType(genericEventType)
+    : X11EventFilter(eventType, opcode, QVector<int>{genericEventType})
+{
+}
+
+X11EventFilter::X11EventFilter(int eventType, int opcode, const QVector< int > 
&genericEventTypes)
+    : m_eventType(eventType), m_extension(opcode), 
m_genericEventTypes(genericEventTypes)
 {
     Workspace::self()->registerEventFilter(this);
 }
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kwin-5.7.3/x11eventfilter.h 
new/kwin-5.7.4/x11eventfilter.h
--- old/kwin-5.7.3/x11eventfilter.h     2016-08-02 11:40:08.000000000 +0200
+++ new/kwin-5.7.4/x11eventfilter.h     2016-08-23 14:46:16.000000000 +0200
@@ -23,6 +23,8 @@
 
 #include <xcb/xcb.h>
 
+#include <QVector>
+
 #include <kwin_export.h>
 
 namespace KWin
@@ -35,6 +37,7 @@
      * Creates an event filter for the given event type.
      */
     X11EventFilter(int eventType, int opcode = 0, int genericEventType = 0);
+    X11EventFilter(int eventType, int opcode, const QVector<int> 
&genericEventTypes);
 
     /**
      * Destroys the event filter.
@@ -54,11 +57,11 @@
     int extension() const { return m_extension; }
 
     /**
      * Returns the type of generic events to filter.
      *
      * Only used when the event type is XCB_GE_GENERIC.
      */
-    int genericEventType() const { return m_genericEventType; }
+    QVector<int> genericEventTypes() const { return m_genericEventTypes; }
 
     /**
      * This method is called for every event of the filtered type.
@@ -70,7 +73,7 @@
 private:
     int m_eventType;
     int m_extension;
-    int m_genericEventType;
+    QVector<int> m_genericEventTypes;
 };
 
 } // namespace KWin
@@ -54,11 +57,11 @@
 
     /**
-     * Returns the type of generic events to filter.
+     * Returns the types of generic events to filter.
      *
      * Only used when the event type is XCB_GE_GENERIC.


Reply via email to